@@ -45,7 +45,7 @@ class Webapp():
         """
         self.__webapp.AddParameter(parameter, branch, portuguese_value, english_value, spanish_value)
 
-    def AssertFalse(self):
+    def AssertFalse(self, expected=False, scritp_message=''):
         """
         Defines that the test case expects a False response to pass
 
@@ -56,9 +56,9 @@ class Webapp():
         >>> #Calling the method
         >>> inst.oHelper.AssertFalse()
         """
-        self.__webapp.AssertFalse()
+        self.__webapp.AssertFalse(expected, scritp_message)
 
-    def AssertTrue(self):
+    def AssertTrue(self, expected=True, scritp_message=''):
         """
         Defines that the test case expects a True response to pass
 
@@ -69,7 +69,7 @@ class Webapp():
         >>> #Calling the method
         >>> inst.oHelper.AssertTrue()
         """
-        self.__webapp.AssertTrue()
+        self.__webapp.AssertTrue(expected, scritp_message)
 
     def ChangeEnvironment(self, date="", group="", branch="", module=""):
         """
@@ -133,9 +133,9 @@ class Webapp():
         :param name_attr: Boolean if search by Name attribute must be forced. - **Default:** False
         :type name_attr: bool
         :param input_field: False if the desired field is not an input type .
-        :type bool
+        :type input_field: bool
         :param direction: Desired direction to search for the element, currently accepts right and down.
-        :type str
+        :type direction: str
 
         Usage:
 
@@ -1195,6 +1195,47 @@ class Webapp():
         """
         return self.__webapp.get_config_value(json_key)
 
+    def ReportComparison(self, base_file="", current_file=""):
+        """
+
+        Compare two reports files and if exists show the difference between then if exists.
+
+        .. warning::
+            Important to use BaseLine_Spool key in config.json to work appropriately. Baseline_Spool is the path of report spool in yout environment
+
+        .. warning::
+            Some words are changed to this pattern below:
+
+            'Emissão: 01-01-2015'
+            'Emision: 01-01-2015'
+            'DT.Ref.: 01-01-2015'
+            'Fc.Ref.: 01-01-2015'
+            'Hora...: 00:00:00'
+            'Hora Término: 00:00:00'
+            '/' to '@'
+
+            Only .xml
+
+            'encoding=""'
+            '"DateTime">2015-01-01T00:00:00'
+            'ss:Width="100"'
+
+        :param base_file: Base file that reflects the expected. If doesn't exist make a copy of auto and then rename to base
+        :type base_file: str
+        :param current_file: Current file recently impressed, this file is use to generate file_auto automatically.
+        :type current_file: str
+
+        Usage:
+
+        >>> # File example:
+        >>> # acda080rbase.##r
+        >>> # acda080rauto.##r
+        >>> # Calling the method:
+        >>> self.oHelper.ReportComparison(base_file="acda080rbase.##r", current_file="acda080rauto.##r")
+        """
+
+        return self.__webapp.report_comparison(base_file, current_file)
+
 class Apw():
 
     def __init__(self, config_path=""):
